# SMT Metamodel

[![PyPI](https://img.shields.io/pypi/v/flamapy-smt)](https://pypi.org/project/flamapy-smt/) ![PyPI - Python Version](https://img.shields.io/pypi/pyversions/flamapy-smt) [![GitHub](https://img.shields.io/github/license/GermanMT/smt_metamodel?logo=gnu)](https://github.com/GermanMT/smt_metamodel/blob/main/LICENSE.md)

This repo host the SMT model concrete classes
